==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/th/persian.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "อังคารที่แล้ว",
	"field-year": "ปี",
	"field-wed-relative+0": "พุธนี้",
	"field-wed-relative+1": "พุธหน้า",
	"field-minute": "นาที",
	"field-month-narrow-relative+-1": "เดือนที่แล้ว",
	"field-tue-narrow-relative+0": "อังคารนี้",
	"field-tue-narrow-relative+1": "อังคารหน้า",
	"field-thu-short-relative+0": "พฤหัสนี้",
	"field-day-short-relative+-1": "เมื่อวาน",
	"field-thu-short-relative+1": "พฤหัสหน้า",
	"field-day-relative+0": "วันนี้",
	"field-day-short-relative+-2": "เมื่อวานซืน",
	"field-day-relative+1": "พรุ่งนี้",
	"field-week-narrow-relative+0": "สัปดาห์นี้",
	"field-day-relative+2": "มะรืนนี้",
	"field-week-narrow-relative+1": "สัปดาห์หน้า",
	"field-wed-narrow-relative+-1": "พุธที่ผ่านมา",
	"field-year-narrow": "ปี",
	"field-year-narrow-relative+0": "ปีนี้",
	"field-tue-relative+0": "อังคารนี้",
	"field-year-narrow-relative+1": "ปีหน้า",
	"field-tue-relative+1": "อังคารหน้า",
	"field-second-short": "วิ",
	"dayPeriods-format-narrow-am": "a",
	"dateFormatItem-MMMd": "d MMM",
	"dayPeriods-format-abbr-am": "ก่อนเที่ยง",
	"field-week-relative+0": "สัปดาห์นี้",
	"field-month-relative+0": "เดือนนี้",
	"field-week-relative+1": "สัปดาห์หน้า",
	"field-month-relative+1": "เดือนหน้า",
	"field-sun-narrow-relative+0": "วันอาทิตย์นี้",
	"field-mon-short-relative+0": "จันทร์นี้",
	"field-sun-narrow-relative+1": "วันอาทิตย์หน้า",
	"field-mon-short-relative+1": "จันทร์หน้า",
	"field-second-relative+0": "ขณะนี้",
	"dateFormatItem-yyyyQQQ": "QQQ G y",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"eraNames": [
		"ปีเปอร์เซีย"
	],
	"dayPeriods-standAlone-abbr-pm": "หลังเที่ยง",
	"field-month-short": "เดือน",
	"dateFormatItem-GyMMMEd": "E d MMM G y",
	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
	"field-day": "วัน",
	"field-year-relative+-1": "ปีที่แล้ว",
	"dayPeriods-format-wide-am": "ก่อนเที่ยง",
	"field-sat-short-relative+-1": "เสาร์ที่แล้ว",
	"field-hour-relative+0": "ชั่วโมงนี้",
	"dateFormatItem-yyyyMEd": "E d/M/y GGGGG",
	"field-wed-relative+-1": "พุธที่แล้ว",
	"field-sat-narrow-relative+-1": "เสาร์ที่ผ่านมา",
	"field-second": "วินาที",
	"days-standAlone-narrow": [
		"อา",
		"จ",
		"อ",
		"พ",
		"พฤ",
		"ศ",
		"ส"
	],
	"dayPeriods-standAlone-wide-pm": "หลังเที่ยง",
	"dateFormat-long": "d MMMM G y",
	"dateFormatItem-GyMMMd": "d MMM G y",
	"field-quarter": "ไตรมาส",
	"field-week-short": "สัปดาห์",
	"field-day-narrow-relative+0": "วันนี้",
	"field-day-narrow-relative+1": "พรุ่งนี้",
	"field-day-narrow-relative+2": "มะรืนนี้",
	"quarters-standAlone-wide": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"days-format-narrow": [
		"อา",
		"จ",
		"อ",
		"พ",
		"พฤ",
		"ศ",
		"ส"
	],
	"field-tue-short-relative+0": "อังคารนี้",
	"field-tue-short-relative+1": "อังคารหน้า",
	"field-month-short-relative+-1": "เดือนที่แล้ว",
	"field-mon-relative+-1": "จันทร์ที่แล้ว",
	"dateFormatItem-GyMMM": "MMM G y",
	"field-month": "เดือน",
	"field-day-narrow": "วัน",
	"field-minute-short": "น.",
	"field-dayperiod": "ช่วงวัน",
	"field-sat-short-relative+0": "เสาร์นี้",
	"field-sat-short-relative+1": "เสาร์หน้า",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormat-medium": "d MMM G y",
	"dateFormatItem-yyyyMMMM": "MMMM G y",
	"eraAbbr": [
		"ปีเปอร์เซีย"
	],
	"quarters-standAlone-abbr": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"dayPeriods-format-abbr-pm": "หลังเที่ยง",
	"dateFormatItem-yyyyM": "M/y G",
	"field-second-narrow": "วิ",
	"field-mon-relative+0": "จันทร์นี้",
	"field-mon-relative+1": "จันทร์หน้า",
	"field-day-narrow-relative+-1": "เมื่อวาน",
	"field-year-short": "ปี",
	"field-day-narrow-relative+-2": "เมื่อวานซืน",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+-1": "ไตรมาสที่แล้ว",
	"dateFormatItem-yyyyMMMd": "d MMM G y",
	"dayPeriods-standAlone-narrow-am": "ก่อนเที่ยง",
	"field-week-narrow-relative+-1": "สัปดาห์ที่แล้ว",
	"days-format-short": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"dayPeriods-format-wide-pm": "หลังเที่ยง",
	"field-sat-relative+-1": "เสาร์ที่แล้ว",
	"dateFormatItem-Md": "d/M",
	"field-hour": "ชั่วโมง",
	"months-format-wide": [
		"ฟาร์วาร์ดิน",
		"ออร์ดิเบเฮชต์",
		"คอร์แดด",
		"เตอร์",
		"มอร์แดด",
		"ชาหริวาร์",
		"เมฮร์",
		"อะบาน",
		"อะซาร์",
		"เดย์",
		"บาฮ์มาน",
		"เอสฟานด์"
	],
	"dateFormat-full": "EEEEที่ d MMMM G y",
	"field-month-relative+-1": "เดือนที่แล้ว",
	"field-quarter-short": "ไตรมาส",
	"field-sat-narrow-relative+0": "เสาร์นี้",
	"field-fri-relative+0": "ศุกร์นี้",
	"field-sat-narrow-relative+1": "เสาร์หน้า",
	"field-fri-relative+1": "ศุกร์หน้า",
	"field-month-narrow-relative+0": "เดือนนี้",
	"field-month-narrow-relative+1": "เดือนหน้า",
	"field-sun-short-relative+0": "วันอาทิตย์นี้",
	"field-sun-short-relative+1": "วันอาทิตย์หน้า",
	"field-week-relative+-1": "สัปดาห์ที่แล้ว",
	"months-format-abbr": [
		"ฟาร์วาร์ดิน",
		"ออร์ดิเบเฮชต์",
		"คอร์แดด",
		"เตอร์",
		"มอร์แดด",
		"ชาหริวาร์",
		"เมฮร์",
		"อะบาน",
		"อะซาร์",
		"เดย์",
		"บาฮ์มาน",
		"เอสฟานด์"
	],
	"field-quarter-relative+0": "ไตรมาสนี้",
	"field-minute-relative+0": "นาทีนี้",
	"timeFormat-long": "H นาฬิกา mm นาที ss วินาที z",
	"field-quarter-relative+1": "ไตรมาสหน้า",
	"field-wed-short-relative+-1": "พุธที่แล้ว",
	"dateFormat-short": "d/M/y G",
	"field-thu-short-relative+-1": "พฤหัสที่แล้ว",
	"field-year-narrow-relative+-1": "ปีที่แล้ว",
	"days-standAlone-wide": [
		"วันอาทิตย์",
		"วันจันทร์",
		"วันอังคาร",
		"วันพุธ",
		"วันพฤหัสบดี",
		"วันศุกร์",
		"วันเสาร์"
	],
	"dateFormatItem-yyyyMMMEd": "E d MMM G y",
	"field-mon-narrow-relative+-1": "จันทร์ที่ผ่านมา",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "พฤหัสที่ผ่านมา",
	"field-tue-narrow-relative+-1": "อังคารที่ผ่านมา",
	"dayPeriods-standAlone-narrow-pm": "หลังเที่ยง",
	"field-wed-short-relative+0": "พุธนี้",
	"months-standAlone-wide": [
		"ฟาร์วาร์ดิน",
		"ออร์ดิเบเฮชต์",
		"คอร์แดด",
		"เตอร์",
		"มอร์แดด",
		"ชาหริวาร์",
		"เมฮร์",
		"อะบาน",
		"อะซาร์",
		"เดย์",
		"บาฮ์มาน",
		"เอสฟานด์"
	],
	"field-wed-short-relative+1": "พุธหน้า",
	"field-sun-relative+-1": "วันอาทิตย์ที่แล้ว",
	"days-standAlone-abbr": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"field-weekday": "วันในสัปดาห์",
	"field-day-short-relative+0": "วันนี้",
	"field-sat-relative+0": "เสาร์นี้",
	"field-day-short-relative+1": "พรุ่งนี้",
	"field-sat-relative+1": "เสาร์หน้า",
	"field-day-short-relative+2": "มะรืนนี้",
	"field-week-short-relative+0": "สัปดาห์นี้",
	"field-week-short-relative+1": "สัปดาห์หน้า",
	"months-standAlone-abbr": [
		"ฟาร์วาร์ดิน",
		"ออร์ดิเบเฮชต์",
		"คอร์แดด",
		"เตอร์",
		"มอร์แดด",
		"ชาหริวาร์",
		"เมฮร์",
		"อะบาน",
		"อะซาร์",
		"เดย์",
		"บาฮ์มาน",
		"เอสฟานด์"
	],
	"field-month-short-relative+0": "เดือนนี้",
	"field-month-short-relative+1": "เดือนหน้า",
	"timeFormat-full": "H นาฬิกา mm นาที ss วินาที zzzz",
	"dateFormatItem-MEd": "E d/M",
	"field-thu-narrow-relative+0": "พฤหัสนี้",
	"field-thu-narrow-relative+1": "พฤหัสหน้า",
	"field-sun-narrow-relative+-1": "วันอาทิตย์ที่แล้ว",
	"field-mon-short-relative+-1": "จันทร์ที่แล้ว",
	"field-thu-relative+0": "พฤหัสนี้",
	"field-thu-relative+1": "พฤหัสหน้า",
	"field-fri-short-relative+-1": "ศุกร์ที่แล้ว",
	"field-thu-relative+-1": "พฤหัสที่แล้ว",
	"field-week": "สัปดาห์",
	"quarters-format-wide": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "พุธนี้",
	"field-wed-narrow-relative+1": "พุธหน้า",
	"field-year-short-relative+0": "ปีนี้",
	"dateFormatItem-yyyyMMM": "MMM G y",
	"field-year-short-relative+1": "ปีหน้า",
	"field-fri-short-relative+0": "ศุกร์นี้",
	"field-fri-short-relative+1": "ศุกร์หน้า",
	"days-standAlone-short": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"field-week-short-relative+-1": "สัปดาห์ที่แล้ว",
	"dateFormatItem-yyyyQQQQ": "QQQQ G y",
	"field-hour-short": "ชม.",
	"quarters-format-abbr": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"field-month-narrow": "เดือน",
	"field-hour-narrow": "ชม.",
	"field-fri-narrow-relative+-1": "ศุกร์ที่ผ่านมา",
	"field-year-relative+0": "ปีนี้",
	"field-year-relative+1": "ปีหน้า",
	"field-fri-relative+-1": "ศุกร์ที่แล้ว",
	"eraNarrow": [
		"ปีเปอร์เซีย"
	],
	"field-tue-short-relative+-1": "อังคารที่แล้ว",
	"field-minute-narrow": "น.",
	"days-format-wide": [
		"วันอาทิตย์",
		"วันจันทร์",
		"วันอังคาร",
		"วันพุธ",
		"วันพฤหัสบดี",
		"วันศุกร์",
		"วันเสาร์"
	],
	"field-mon-narrow-relative+0": "จันทร์นี้",
	"field-mon-narrow-relative+1": "จันทร์หน้า",
	"field-year-short-relative+-1": "ปีที่แล้ว",
	"field-zone": "เขตเวลา",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-quarter-narrow": "ไตรมาส",
	"field-sun-short-relative+-1": "วันอาทิตย์ที่แล้ว",
	"field-day-relative+-1": "เมื่อวาน",
	"dayPeriods-standAlone-abbr-am": "ก่อนเที่ยง",
	"field-day-relative+-2": "เมื่อวานซืน",
	"days-format-abbr": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"field-sun-relative+0": "วันอาทิตย์นี้",
	"field-sun-relative+1": "วันอาทิตย์หน้า",
	"field-day-short": "วัน",
	"field-week-narrow": "สัปดาห์",
	"field-era": "สมัย",
	"field-fri-narrow-relative+0": "ศุกร์นี้",
	"field-fri-narrow-relative+1": "ศุกร์หน้า",
	"dayPeriods-standAlone-wide-am": "ก่อนเที่ยง"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/th/persian.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ไตรมาสนี้",
	"field-quarter-short-relative+1": "ไตรมาสหน้า",
	"field-tue-relative+-1": "อังคารที่แล้ว",
	"field-year": "ปี",
	"field-wed-relative+0": "พุธนี้",
	"field-wed-relative+1": "พุธหน้า",
	"field-minute": "นาที",
	"field-month-narrow-relative+-1": "เดือนที่แล้ว",
	"field-tue-narrow-relative+0": "อังคารนี้",
	"field-tue-narrow-relative+1": "อังคารหน้า",
	"field-thu-short-relative+0": "พฤหัสนี้",
	"field-day-short-relative+-1": "เมื่อวาน",
	"field-thu-short-relative+1": "พฤหัสหน้า",
	"field-day-relative+0": "วันนี้",
	"field-day-short-relative+-2": "เมื่อวานซืน",
	"field-day-relative+1": "พรุ่งนี้",
	"field-week-narrow-relative+0": "สัปดาห์นี้",
	"field-day-relative+2": "มะรืนนี้",
	"field-week-narrow-relative+1": "สัปดาห์หน้า",
	"field-wed-narrow-relative+-1": "พุธที่แล้ว",
	"field-year-narrow": "ปี",
	"field-era-short": "สมัย",
	"field-year-narrow-relative+0": "ปีนี้",
	"field-tue-relative+0": "อังคารนี้",
	"field-year-narrow-relative+1": "ปีหน้า",
	"field-tue-relative+1": "อังคารหน้า",
	"field-weekdayOfMonth": "วันของเดือน",
	"field-second-short": "วิ",
	"dayPeriods-format-narrow-am": "a",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "วันของเดือน",
	"dayPeriods-format-abbr-am": "ก่อนเที่ยง",
	"field-week-relative+0": "สัปดาห์นี้",
	"field-month-relative+0": "เดือนนี้",
	"field-week-relative+1": "สัปดาห์หน้า",
	"field-month-relative+1": "เดือนหน้า",
	"field-sun-narrow-relative+0": "วันอาทิตย์นี้",
	"field-mon-short-relative+0": "จันทร์นี้",
	"field-sun-narrow-relative+1": "วันอาทิตย์หน้า",
	"field-mon-short-relative+1": "จันทร์หน้า",
	"field-second-relative+0": "ขณะนี้",
	"dateFormatItem-yyyyQQQ": "QQQ G y",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"eraNames": [
		"ปีเปอร์เซีย"
	],
	"field-weekOfMonth": "สัปดาห์ของเดือน",
	"dayPeriods-standAlone-abbr-pm": "หลังเที่ยง",
	"field-month-short": "เดือน",
	"dateFormatItem-GyMMMEd": "E d MMM G y",
	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
	"field-day": "วัน",
	"field-dayOfYear-short": "วันของปี",
	"field-year-relative+-1": "ปีที่แล้ว",
	"dayPeriods-format-wide-am": "ก่อนเที่ยง",
	"field-sat-short-relative+-1": "เสาร์ที่แล้ว",
	"field-hour-relative+0": "ชั่วโมงนี้",
	"dateFormatItem-yyyyMEd": "E d/M/y GGGGG",
	"field-wed-relative+-1": "พุธที่แล้ว",
	"field-sat-narrow-relative+-1": "เสาร์ที่แล้ว",
	"field-second": "วินาที",
	"days-standAlone-narrow": [
		"อา",
		"จ",
		"อ",
		"พ",
		"พฤ",
		"ศ",
		"ส"
	],
	"dayPeriods-standAlone-wide-pm": "หลังเที่ยง",
	"dateFormat-long": "d MMMM G y",
	"dateFormatItem-GyMMMd": "d MMM G y",
	"field-quarter": "ไตรมาส",
	"field-week-short": "สัปดาห์",
	"field-day-narrow-relative+0": "วันนี้",
	"field-day-narrow-relative+1": "พรุ่งนี้",
	"field-day-narrow-relative+2": "มะรืนนี้",
	"quarters-standAlone-wide": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"days-format-narrow": [
		"อา",
		"จ",
		"อ",
		"พ",
		"พฤ",
		"ศ",
		"ส"
	],
	"field-tue-short-relative+0": "อังคารนี้",
	"field-tue-short-relative+1": "อังคารหน้า",
	"field-month-short-relative+-1": "เดือนที่แล้ว",
	"field-mon-relative+-1": "จันทร์ที่แล้ว",
	"dateFormatItem-GyMMM": "MMM G y",
	"field-month": "เดือน",
	"field-day-narrow": "วัน",
	"field-dayperiod": "ช่วงวัน",
	"field-sat-short-relative+0": "เสาร์นี้",
	"field-sat-short-relative+1": "เสาร์หน้า",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormat-medium": "d MMM G y",
	"dateFormatItem-yyyyMMMM": "MMMM G y",
	"eraAbbr": [
		"ปีเปอร์เซีย"
	],
	"quarters-standAlone-abbr": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"dayPeriods-format-abbr-pm": "หลังเที่ยง",
	"dateFormatItem-yyyyM": "M/y G",
	"field-second-narrow": "วิ",
	"field-mon-relative+0": "จันทร์นี้",
	"field-mon-relative+1": "จันทร์หน้า",
	"field-day-narrow-relative+-1": "เมื่อวาน",
	"field-year-short": "ปี",
	"field-day-narrow-relative+-2": "เมื่อวานซืน",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+-1": "ไตรมาสที่แล้ว",
	"dateFormatItem-yyyyMMMd": "d MMM G y",
	"field-dayperiod-narrow": "ช่วงวัน",
	"dayPeriods-standAlone-narrow-am": "ก่อนเที่ยง",
	"field-week-narrow-relative+-1": "สัปดาห์ที่แล้ว",
	"days-format-short": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"dayPeriods-format-wide-pm": "หลังเที่ยง",
	"field-dayOfYear": "วันของปี",
	"field-sat-relative+-1": "เสาร์ที่แล้ว",
	"dateFormatItem-Md": "d/M",
	"field-hour": "ชั่วโมง",
	"months-format-wide": [
		"ฟาร์วาร์ดิน",
		"ออร์ดิเบเฮชต์",
		"คอร์แดด",
		"เตอร์",
		"มอร์แดด",
		"ชาหริวาร์",
		"เมฮร์",
		"อะบาน",
		"อะซาร์",
		"เดย์",
		"บาฮ์มาน",
		"เอสฟานด์"
	],
	"dateFormat-full": "EEEEที่ d MMMM G y",
	"field-month-relative+-1": "เดือนที่แล้ว",
	"field-quarter-short": "ไตรมาส",
	"field-sat-narrow-relative+0": "เสาร์นี้",
	"field-fri-relative+0": "ศุกร์นี้",
	"field-sat-narrow-relative+1": "เสาร์หน้า",
	"field-fri-relative+1": "ศุกร์หน้า",
	"field-month-narrow-relative+0": "เดือนนี้",
	"field-month-narrow-relative+1": "เดือนหน้า",
	"field-sun-short-relative+0": "วันอาทิตย์นี้",
	"field-sun-short-relative+1": "วันอาทิตย์หน้า",
	"field-week-relative+-1": "สัปดาห์ที่แล้ว",
	"field-quarter-short-relative+-1": "ไตรมาสที่แล้ว",
	"months-format-abbr": [
		"ฟาร์วาร์ดิน",
		"ออร์ดิเบเฮชต์",
		"คอร์แดด",
		"เตอร์",
		"มอร์แดด",
		"ชาหริวาร์",
		"เมฮร์",
		"อะบาน",
		"อะซาร์",
		"เดย์",
		"บาฮ์มาน",
		"เอสฟานด์"
	],
	"field-quarter-relative+0": "ไตรมาสนี้",
	"field-minute-relative+0": "นาทีนี้",
	"timeFormat-long": "H นาฬิกา mm นาที ss วินาที z",
	"field-quarter-relative+1": "ไตรมาสหน้า",
	"field-wed-short-relative+-1": "พุธที่แล้ว",
	"dateFormat-short": "d/M/y G",
	"field-thu-short-relative+-1": "พฤหัสที่แล้ว",
	"field-year-narrow-relative+-1": "ปีที่แล้ว",
	"days-standAlone-wide": [
		"วันอาทิตย์",
		"วันจันทร์",
		"วันอังคาร",
		"วันพุธ",
		"วันพฤหัสบดี",
		"วันศุกร์",
		"วันเสาร์"
	],
	"dateFormatItem-yyyyMMMEd": "E d MMM G y",
	"field-mon-narrow-relative+-1": "จันทร์ที่แล้ว",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "พฤหัสที่แล้ว",
	"field-tue-narrow-relative+-1": "อังคารที่แล้ว",
	"field-weekOfMonth-short": "สัปดาห์ของเดือน",
	"dayPeriods-standAlone-narrow-pm": "หลังเที่ยง",
	"field-wed-short-relative+0": "พุธนี้",
	"months-standAlone-wide": [
		"ฟาร์วาร์ดิน",
		"ออร์ดิเบเฮชต์",
		"คอร์แดด",
		"เตอร์",
		"มอร์แดด",
		"ชาหริวาร์",
		"เมฮร์",
		"อะบาน",
		"อะซาร์",
		"เดย์",
		"บาฮ์มาน",
		"เอสฟานด์"
	],
	"field-wed-short-relative+1": "พุธหน้า",
	"field-sun-relative+-1": "วันอาทิตย์ที่แล้ว",
	"days-standAlone-abbr": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"field-weekday": "วันของสัปดาห์",
	"field-day-short-relative+0": "วันนี้",
	"field-quarter-narrow-relative+0": "ไตรมาสนี้",
	"field-day-short-relative+1": "พรุ่งนี้",
	"field-sat-relative+0": "เสาร์นี้",
	"field-quarter-narrow-relative+1": "ไตรมาสหน้า",
	"field-day-short-relative+2": "มะรืนนี้",
	"field-sat-relative+1": "เสาร์หน้า",
	"field-week-short-relative+0": "สัปดาห์นี้",
	"field-week-short-relative+1": "สัปดาห์หน้า",
	"months-standAlone-abbr": [
		"ฟาร์วาร์ดิน",
		"ออร์ดิเบเฮชต์",
		"คอร์แดด",
		"เตอร์",
		"มอร์แดด",
		"ชาหริวาร์",
		"เมฮร์",
		"อะบาน",
		"อะซาร์",
		"เดย์",
		"บาฮ์มาน",
		"เอสฟานด์"
	],
	"field-dayOfYear-narrow": "วันของปี",
	"field-month-short-relative+0": "เดือนนี้",
	"field-month-short-relative+1": "เดือนหน้า",
	"field-weekdayOfMonth-short": "วันของเดือน",
	"timeFormat-full": "H นาฬิกา mm นาที ss วินาที zzzz",
	"dateFormatItem-MEd": "E d/M",
	"field-zone-narrow": "เขตเวลา",
	"field-thu-narrow-relative+0": "พฤหัสนี้",
	"field-thu-narrow-relative+1": "พฤหัสหน้า",
	"field-sun-narrow-relative+-1": "วันอาทิตย์ที่แล้ว",
	"field-mon-short-relative+-1": "จันทร์ที่แล้ว",
	"field-thu-relative+0": "พฤหัสนี้",
	"field-thu-relative+1": "พฤหัสหน้า",
	"field-fri-short-relative+-1": "ศุกร์ที่แล้ว",
	"field-thu-relative+-1": "พฤหัสที่แล้ว",
	"field-week": "สัปดาห์",
	"quarters-format-wide": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "พุธนี้",
	"field-wed-narrow-relative+1": "พุธหน้า",
	"field-quarter-narrow-relative+-1": "ไตรมาสที่แล้ว",
	"field-year-short-relative+0": "ปีนี้",
	"field-dayperiod-short": "ช่วงวัน",
	"dateFormatItem-yyyyMMM": "MMM G y",
	"field-year-short-relative+1": "ปีหน้า",
	"field-fri-short-relative+0": "ศุกร์นี้",
	"field-fri-short-relative+1": "ศุกร์หน้า",
	"days-standAlone-short": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"field-week-short-relative+-1": "สัปดาห์ที่แล้ว",
	"dateFormatItem-yyyyQQQQ": "QQQQ G y",
	"field-hour-short": "ชม.",
	"field-zone-short": "โซน",
	"quarters-format-abbr": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"field-month-narrow": "เดือน",
	"field-hour-narrow": "ชม.",
	"field-fri-narrow-relative+-1": "ศุกร์ที่แล้ว",
	"field-year-relative+0": "ปีนี้",
	"field-year-relative+1": "ปีหน้า",
	"field-era-narrow": "สมัย",
	"field-fri-relative+-1": "ศุกร์ที่แล้ว",
	"eraNarrow": [
		"ปีเปอร์เซีย"
	],
	"field-tue-short-relative+-1": "อังคารที่แล้ว",
	"field-minute-narrow": "นาที",
	"days-format-wide": [
		"วันอาทิตย์",
		"วันจันทร์",
		"วันอังคาร",
		"วันพุธ",
		"วันพฤหัสบดี",
		"วันศุกร์",
		"วันเสาร์"
	],
	"field-mon-narrow-relative+0": "จันทร์นี้",
	"field-mon-narrow-relative+1": "จันทร์หน้า",
	"field-year-short-relative+-1": "ปีที่แล้ว",
	"field-zone": "เขตเวลา",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-weekOfMonth-narrow": "สัปดาห์ของเดือน",
	"field-weekday-narrow": "วันของสัปดาห์",
	"field-quarter-narrow": "ไตรมาส",
	"field-sun-short-relative+-1": "วันอาทิตย์ที่แล้ว",
	"field-day-relative+-1": "เมื่อวาน",
	"dayPeriods-standAlone-abbr-am": "ก่อนเที่ยง",
	"field-day-relative+-2": "เมื่อวานซืน",
	"field-weekday-short": "วันของสัปดาห์",
	"days-format-abbr": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"field-sun-relative+0": "วันอาทิตย์นี้",
	"field-sun-relative+1": "วันอาทิตย์หน้า",
	"field-day-short": "วัน",
	"field-week-narrow": "สัปดาห์",
	"field-era": "สมัย",
	"field-fri-narrow-relative+0": "ศุกร์นี้",
	"field-fri-narrow-relative+1": "ศุกร์หน้า",
	"dayPeriods-standAlone-wide-am": "ก่อนเที่ยง"
}
//end v1.x content
);
